@@ -43,7 +43,9 @@ import molecule.scenarios
 
 from molecule import config, logger, text, util
 from molecule.console import should_do_markup
+from molecule.exceptions import ScenarioFailureError
 from molecule.scenario import Scenario
+from molecule.util import safe_dump
 
 
 if TYPE_CHECKING:
@@ -51,7 +53,7 @@ if TYPE_CHECKING:
     from typing import NoReturn
 
     from molecule.scenario import Scenario
-    from molecule.types import CommandArgs, MoleculeArgs
+    from molecule.types import CommandArgs, MoleculeArgs, ScenariosResults
 
     ClickCommand = Callable[[Callable[..., None]], click.Command]
     ClickGroup = Callable[[Callable[..., None]], click.Group]
@@ -99,10 +101,11 @@ class Base(abc.ABC):
 
 
 def execute_cmdline_scenarios(
-    scenario_name: str | None,
+    scenario_names: list[str] | None,
     args: MoleculeArgs,
     command_args: CommandArgs,
     ansible_args: tuple[str, ...] = (),
+    excludes: list[str] | None = None,
 ) -> None:
     """Execute scenario sequences based on parsed command-line arguments.
 
@@ -113,29 +116,81 @@ def execute_cmdline_scenarios(
     to generate the scenario(s) configuration.
 
     Args:
-        scenario_name: Name of scenario to run, or ``None`` to run all.
+        scenario_names: Name of scenarios to run, or ``None`` to run all.
         args: ``args`` dict from ``click`` command context
         command_args: dict of command arguments, including the target
         ansible_args: Optional tuple of arguments to pass to the `ansible-playbook` command
+        excludes: Name of scenarios to not run.
+    """
+    if excludes is None:
+        excludes = []
 
-    Raises:
-        SystemExit: If scenario exits prematurely.
+    configs: list[config.Config] = []
+    if scenario_names is None:
+        configs = [
+            config
+            for config in get_configs(args, command_args, ansible_args, MOLECULE_GLOB)
+            if config.scenario.name not in excludes
+        ]
+    else:
+        # filter out excludes
+        scenario_names = [name for name in scenario_names if name not in excludes]
+        for scenario_name in scenario_names:
+            glob_str = MOLECULE_GLOB.replace("*", scenario_name)
+            configs.extend(get_configs(args, command_args, ansible_args, glob_str))
+
+    scenarios = _generate_scenarios(scenario_names, configs)
+
+    try:
+        _run_scenarios(scenarios, command_args)
+
+    except ScenarioFailureError as exc:
+        util.sysexit(code=exc.code)
+    finally:
+        if command_args.get("report"):
+            print(generate_report(scenarios.results))  # noqa: T201
+
+
+def _generate_scenarios(
+    scenario_names: list[str] | None,
+    configs: list[config.Config],
+) -> molecule.scenarios.Scenarios:
+    """Generate Scenarios object from names and configs.
+
+    Args:
+        scenario_names: Names of scenarios to include.
+        configs: List of Config objects to consider.
+
+    Returns:
+        Combined Scenarios object.
     """
-    glob_str = MOLECULE_GLOB
-    if scenario_name:
-        glob_str = glob_str.replace("*", scenario_name)
     scenarios = molecule.scenarios.Scenarios(
-        get_configs(args, command_args, ansible_args, glob_str),
-        scenario_name,
+        configs,
+        scenario_names,
     )
 
-    if scenario_name and scenarios:
-        LOG.info(
-            "%s scenario test matrix: %s",
-            scenario_name,
-            ", ".join(scenarios.sequence(scenario_name)),
-        )
+    if scenario_names is not None:
+        for scenario_name in scenario_names:
+            if scenario_name != "*" and scenarios:
+                LOG.info(
+                    "%s scenario test matrix: %s",
+                    scenario_name,
+                    ", ".join(scenarios.sequence(scenario_name)),
+                )
 
+    return scenarios
+
+
+def _run_scenarios(scenarios: molecule.scenarios.Scenarios, command_args: CommandArgs) -> None:
+    """Loop through Scenarios object and execute each.
+
+    Args:
+        scenarios: The Scenarios object holding all of the Scenario objects.
+        command_args: dict of command arguments.
+
+    Raises:
+        ScenarioFailureError: when a scenario fails prematurely.
+    """
     for scenario in scenarios:
         if scenario.config.config["prerun"]:
             role_name_check = scenario.config.config["role_name_check"]
@@ -151,6 +206,22 @@ def execute_cmdline_scenarios(
             return
         try:
             execute_scenario(scenario)
+        except ScenarioFailureError:
+            # if the command has a 'destroy' arg, like test does,
+            # handle that behavior here.
+            if command_args.get("destroy") == "always":
+                msg = (
+                    f"An error occurred during the {scenario.config.subcommand} sequence action: "
+                    f"'{scenario.config.action}'. Cleaning up."
+                )
+                LOG.warning(msg)
+                execute_subcommand(scenario.config, "cleanup")
+                execute_subcommand(scenario.config, "destroy")
+                # always prune ephemeral dir if destroying on failure
+                scenario.prune()
+                if scenario.config.is_parallel:
+                    scenario._remove_scenario_state_directory()  # noqa: SLF001
+            raise
         except SystemExit:
             # if the command has a 'destroy' arg, like test does,
             # handle that behavior here.
@@ -166,9 +237,10 @@ def execute_cmdline_scenarios(
                 scenario.prune()
                 if scenario.config.is_parallel:
                     scenario._remove_scenario_state_directory()  # noqa: SLF001
-                util.sysexit()
-            else:
-                raise
+            raise ScenarioFailureError from None
+        finally:
+            # Store results regardless
+            scenarios.results.append({"name": scenario.name, "results": scenario.results})
 
 
 def execute_subcommand(
@@ -287,17 +359,20 @@ def _verify_configs(configs: list[config.Config], glob_str: str = MOLECULE_GLOB)
     Args:
         configs: A list containing absolute paths to Molecule config files.
         glob_str: A string representing the glob used to find Molecule config files.
+
+    Raises:
+        ScenarioFailureError: When scenario configs cannot be verified.
     """
     if configs:
         scenario_names = [c.scenario.name for c in configs]
         for scenario_name, n in collections.Counter(scenario_names).items():
             if n > 1:
                 msg = f"Duplicate scenario name '{scenario_name}' found.  Exiting."
-                util.sysexit_with_message(msg)
+                raise ScenarioFailureError(message=msg)
 
     else:
         msg = f"'{glob_str}' glob failed.  Exiting."
-        util.sysexit_with_message(msg)
+        raise ScenarioFailureError(message=msg)
 
 
 def _get_subcommand(string: str) -> str:
@@ -364,6 +439,41 @@ def click_command_ex(name: str | None = None) -> ClickCommand:
     )
 
 
+def click_command_options(func: Callable[..., None]) -> Callable[..., None]:
+    """Provide a baseline set of reusable options for molecule actions.
+
+    Args:
+        func: Function to be decorated.
+
+    Returns:
+        Function with click options for scenario_name, exclude, all, and report added.
+    """
+    func = click.option(
+        "--report/--no-report",
+        default=False,
+        help="EXPERIMENTAL: Enable or disable end-of-run summary report. Default is disabled.",
+    )(func)
+    func = click.option(
+        "--exclude",
+        "-e",
+        multiple=True,
+        help="Name of the scenario to exclude from targeting. May be specified multiple times. Can exclude scenarios already included with scenario-name or all.",
+    )(func)
+    func = click.option(
+        "--all/--no-all",
+        "__all",
+        default=False,
+        help="Target all scenarios. Overrides scenario-name. Default is disabled.",
+    )(func)
+    return click.option(
+        "--scenario-name",
+        "-s",
+        multiple=True,
+        default=[MOLECULE_DEFAULT_SCENARIO_NAME],
+        help=f"Name of the scenario to target. May be specified multiple times. ({MOLECULE_DEFAULT_SCENARIO_NAME})",
+    )(func)
+
+
 def result_callback(
     *args: object,  # noqa: ARG001
     **kwargs: object,  # noqa: ARG001
@@ -377,3 +487,15 @@ def result_callback(
     # We want to be used we run out custom exit code, regardless if run was
     # a success or failure.
     util.sysexit(0)
+
+
+def generate_report(results: list[ScenariosResults]) -> str:
+    """Print end-of-run report.
+
+    Args:
+        results: Dictionary containing results from each scenario.
+
+    Returns:
+        The formatted end-of-run report.
+    """
+    return safe_dump(results)
