@@ -22,11 +22,17 @@ from __future__ import annotations
 
 import logging
 
+from typing import TYPE_CHECKING
+
 import click
 
 from molecule.command import base
 
 
+if TYPE_CHECKING:
+    from molecule.types import CommandArgs, MoleculeArgs
+
+
 LOG = logging.getLogger(__name__)
 
 
@@ -34,24 +40,45 @@ class Converge(base.Base):
     """Converge Command Class."""
 
     def execute(self, action_args: list[str] | None = None) -> None:  # noqa: ARG002
-        """Execute the actions necessary to perform a `molecule converge` and returns None."""
-        self._config.provisioner.converge()
-        self._config.state.change_state("converged", True)  # noqa: FBT003
+        """Execute the actions necessary to perform a `molecule converge`.
+
+        Args:
+            action_args: Arguments for this command. Unused.
+        """
+        if self._config.provisioner:
+            self._config.provisioner.converge()
+        self._config.state.change_state("converged", value=True)
 
 
 @base.click_command_ex()
 @click.pass_context
-@click.option(
-    "--scenario-name",
-    "-s",
-    default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
-)
+@base.click_command_options
 @click.argument("ansible_args", nargs=-1, type=click.UNPROCESSED)
-def converge(ctx, scenario_name, ansible_args):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
-    """Use the provisioner to configure instances (dependency, create, prepare converge)."""
-    args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
-    command_args = {"subcommand": subcommand}
+def converge(
+    ctx: click.Context,
+    /,
+    scenario_name: list[str] | None,
+    exclude: list[str],
+    __all: bool,  # noqa: FBT001
+    *,
+    report: bool,
+    ansible_args: tuple[str],
+) -> None:  # pragma: no cover
+    """Use the provisioner to configure instances (dependency, create, prepare converge).
 
-    base.execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args)
+    Args:
+        ctx: Click context object holding commandline arguments.
+        scenario_name: Name of the scenario to target.
+        exclude: Name of the scenarios to avoid targeting.
+        __all: Whether molecule should target scenario_name or all scenarios.
+        report: Whether to show an after-run summary report.
+        ansible_args: Arguments to forward to Ansible.
+    """
+    args: MoleculeArgs = ctx.obj.get("args")
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
+    command_args: CommandArgs = {"subcommand": subcommand, "report": report}
+
+    if __all:
+        scenario_name = None
+
+    base.execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args, exclude)
