@@ -22,34 +22,59 @@ from __future__ import annotations
 
 import logging
 
+from typing import TYPE_CHECKING
+
 import click
 
 from molecule.command import base
 
 
+if TYPE_CHECKING:
+    from molecule.types import CommandArgs, MoleculeArgs
+
+
 LOG = logging.getLogger(__name__)
 
 
 class Dependency(base.Base):
     """Dependency Command Class."""
 
-    def execute(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, ARG002
-        """Execute the actions necessary to perform a `molecule dependency` and returns None."""
-        self._config.dependency.execute()
+    def execute(self, action_args: list[str] | None = None) -> None:  # noqa: ARG002
+        """Execute the actions necessary to perform a `molecule dependency`.
+
+        Args:
+            action_args: Arguments for this command. Unused.
+        """
+        if self._config.dependency:
+            self._config.dependency.execute()
 
 
 @base.click_command_ex()
 @click.pass_context
-@click.option(
-    "--scenario-name",
-    "-s",
-    default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
-)
-def dependency(ctx, scenario_name):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
-    """Manage the role's dependencies."""
-    args = ctx.obj.get("args")
-    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
-    command_args = {"subcommand": subcommand}
+@base.click_command_options
+def dependency(
+    ctx: click.Context,
+    /,
+    scenario_name: list[str] | None,
+    exclude: list[str],
+    *,
+    __all: bool,
+    report: bool,
+) -> None:  # pragma: no cover
+    """Manage the role's dependencies.
 
-    base.execute_cmdline_scenarios(scenario_name, args, command_args)
+    Args:
+        ctx: Click context object holding commandline arguments.
+        scenario_name: Name of the scenario to target.
+        exclude: Name of the scenarios to avoid targeting.
+        __all: Whether molecule should target scenario_name or all scenarios.
+        report: Whether to show an after-run summary report.
+    """
+    args: MoleculeArgs = ctx.obj.get("args")
+    subcommand = base._get_subcommand(__name__)  # noqa: SLF001
+    command_args: CommandArgs = {"subcommand": subcommand, "report": report}
+
+    if __all:
+        scenario_name = None
+
+    base.execute_cmdline_scenarios(scenario_name, args, command_args, excludes=exclude)
