@@ -50,30 +50,15 @@ class Verify(base.Base):
 
 @base.click_command_ex()
 @click.pass_context
-@click.option(
-    "--scenario-name",
-    "-s",
-    multiple=True,
-    default=[base.MOLECULE_DEFAULT_SCENARIO_NAME],
-    help=f"Name of the scenario to target. May be specified multiple times. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
-)
-@click.option(
-    "--all/--no-all",
-    "__all",
-    default=False,
-    help="Verify all scenarios. Default is False.",
-)
-@click.option(
-    "--exclude",
-    "-e",
-    multiple=True,
-    help="Name of the scenario to exclude from running. May be specified multiple times.",
-)
+@base.click_command_options
 def verify(
     ctx: click.Context,
+    /,
     scenario_name: list[str] | None,
     exclude: list[str],
-    __all: bool,  # noqa: FBT001
+    *,
+    __all: bool,
+    report: bool,
 ) -> None:  # pragma: no cover
     """Run automated tests against instances.
 
@@ -82,10 +67,11 @@ def verify(
         scenario_name: Name of the scenario to target.
         exclude: Name of the scenarios to avoid targeting.
         __all: Whether molecule should target scenario_name or all scenarios.
+        report: Whether to show an after-run summary report.
     """
     args: MoleculeArgs = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
-    command_args: CommandArgs = {"subcommand": subcommand}
+    command_args: CommandArgs = {"subcommand": subcommand, "report": report}
 
     if __all:
         scenario_name = None
