@@ -21,13 +21,19 @@
 from __future__ import annotations
 
 import logging
-import os
+
+from pathlib import Path
+from typing import TYPE_CHECKING, Any
 
 from molecule import util
-from molecule.api import Driver  # type: ignore[attr-defined]
+from molecule.api import Driver
 from molecule.data import __file__ as data_module
 
 
+if TYPE_CHECKING:
+    from molecule.config import Config
+
+
 LOG = logging.getLogger(__name__)
 
 
@@ -138,25 +144,47 @@ class Delegated(Driver):
             ansible_connection_options:
               ansible_connection: local
     ```
+
+    Attributes:
+        title: Short description of the driver.
     """
 
     title = "Default driver, user is expected to manage provisioning of test resources."
 
-    def __init__(self, config=None) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001
-        """Construct Delegated."""
+    def __init__(self, config: Config) -> None:
+        """Construct Delegated.
+
+        Args:
+            config: An instance of a Molecule config.
+        """
         super().__init__(config)
         self._name = "default"
 
     @property
-    def name(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+    def name(self) -> str:
+        """Name of the driver.
+
+        Returns:
+            Name of the driver.
+        """
         return self._name
 
     @name.setter
-    def name(self, value):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202
+    def name(self, value: str) -> None:
+        """Driver name setter.
+
+        Args:
+            value: New name of the driver.
+        """
         self._name = value
 
     @property
-    def login_cmd_template(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+    def login_cmd_template(self) -> str:
+        """Get the login command template to be populated by ``login_options`` as a string.
+
+        Returns:
+            The login command template, if any.
+        """
         if "login_cmd_template" in self.options:
             return self.options["login_cmd_template"]
 
@@ -170,36 +198,62 @@ class Delegated(Driver):
                 "-i {identity_file} "
                 f"{connection_options}"
             )
-        return None
+        return ""
 
     @property
-    def default_safe_files(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+    def default_safe_files(self) -> list[str]:
+        """Generate files to be preserved.
+
+        Returns:
+            List of files to be preserved.
+        """
         return []
 
     @property
-    def default_ssh_connection_options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+    def default_ssh_connection_options(self) -> list[str]:
+        """SSH client options.
+
+        Returns:
+            List of SSH connection options.
+        """
         if self.managed:
-            ssh_connopts = self._get_ssh_connection_options()  # type: ignore[no-untyped-call]
-            if self.options.get("ansible_connection_options", {}).get(
+            ssh_connopts = self._get_ssh_connection_options()
+            if config_connopts := self.options.get("ansible_connection_options", {}).get(
                 "ansible_ssh_common_args",
-                None,
             ):
                 ssh_connopts.append(
-                    self.options.get("ansible_connection_options").get(
-                        "ansible_ssh_common_args",
-                    ),
+                    config_connopts,
                 )
             return ssh_connopts
         return []
 
-    def login_options(self, instance_name):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, D102
+    def login_options(self, instance_name: str) -> dict[str, str]:
+        """Login options.
+
+        Args:
+            instance_name: The name of the instance to look up login options for.
+
+        Returns:
+            Dictionary of options related to logging into the instance.
+        """
         if self.managed:
             d = {"instance": instance_name}
 
-            return util.merge_dicts(d, self._get_instance_config(instance_name))  # type: ignore[no-untyped-call]
+            return util.merge_dicts(d, self._get_instance_config(instance_name))
         return {"instance": instance_name}
 
-    def ansible_connection_options(self, instance_name):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, D102
+    def ansible_connection_options(
+        self,
+        instance_name: str,
+    ) -> dict[str, str]:
+        """Ansible connection options.
+
+        Args:
+            instance_name: The name of the instance to look up Ansible connection options for.
+
+        Returns:
+            Dictionary of options related to ansible connection to the instance.
+        """
         # list of tuples describing mappable instance params and default values
         instance_params = [
             ("become_pass", None),
@@ -213,7 +267,7 @@ class Delegated(Driver):
         ]
         if self.managed:
             try:
-                d = self._get_instance_config(instance_name)  # type: ignore[no-untyped-call]
+                d = self._get_instance_config(instance_name)
                 conn_dict = {}
                 # Check if optional mappable params are in the instance config
                 for i in instance_params:
@@ -228,7 +282,7 @@ class Delegated(Driver):
                     conn_dict["ansible_private_key_file"] = d.get("identity_file")
                 if d.get("password", None):
                     conn_dict["ansible_password"] = d.get("password")
-                    # Based on testinfra documentation, ansible password must be passed via ansible_ssh_pass  # noqa: E501
+                    # Based on testinfra documentation, ansible password must be passed via ansible_ssh_pass
                     # issue to fix this can be found https://github.com/pytest-dev/pytest-testinfra/issues/580
                     conn_dict["ansible_ssh_pass"] = d.get("password")
 
@@ -246,19 +300,24 @@ class Delegated(Driver):
                 return {}
         return self.options.get("ansible_connection_options", {})
 
-    def _created(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+    def _created(self) -> str:
         if self.managed:
-            return super()._created()  # type: ignore[no-untyped-call]
+            return super()._created()
         return "unknown"
 
-    def _get_instance_config(self, instance_name):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202
+    def _get_instance_config(self, instance_name: str) -> dict[str, Any]:
         instance_config_dict = util.safe_load_file(self._config.driver.instance_config)
 
         return next(item for item in instance_config_dict if item["instance"] == instance_name)
 
-    def sanity_checks(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+    def sanity_checks(self) -> None:
+        """Run sanity checks."""
         # Note(decentral1se): Cannot implement driver specifics are unknown
-        pass
 
-    def schema_file(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
-        return os.path.join(os.path.dirname(data_module), "driver.json")  # noqa: PTH118, PTH120
+    def schema_file(self) -> str:
+        """Return schema file path.
+
+        Returns:
+            Path to schema file.
+        """
+        return str(Path(data_module).parent / "driver.json")
